# Changelog

## 0.1.0-alpha.1 (2025-01-15)

Full Changelog: [v0.0.1-alpha.0...v0.1.0-alpha.1](https://github.com/ToricLabs/datagrid-python/compare/v0.0.1-alpha.0...v0.1.0-alpha.1)

### Features

* **api:** api update ([b5d6a8c](https://github.com/ToricLabs/datagrid-python/commit/b5d6a8ca109ee89ad067c52bc2a9742e77e438b8))
* **api:** update via SDK Studio ([9b8b99d](https://github.com/ToricLabs/datagrid-python/commit/9b8b99de5655c824bba0cd1c39ebe86d111e7fda))
* **api:** update via SDK Studio ([4356f22](https://github.com/ToricLabs/datagrid-python/commit/4356f2273f8df43faa7e72caf384a717aeb11283))


### Bug Fixes

* **client:** only call .close() when needed ([49224f5](https://github.com/ToricLabs/datagrid-python/commit/49224f551ffa1cf522b8f915c0150f6b0ccec8b3))
* correctly handle deserialising `cls` fields ([4e06990](https://github.com/ToricLabs/datagrid-python/commit/4e06990be5b8fb76cad39b97dafb0a7b350c45f8))


### Chores

* go live ([#1](https://github.com/ToricLabs/datagrid-python/issues/1)) ([379ce7a](https://github.com/ToricLabs/datagrid-python/commit/379ce7a02b84a30151f647b86ff1ba94d6f1d695))
* **internal:** bump httpx dependency ([413952c](https://github.com/ToricLabs/datagrid-python/commit/413952c264538f97d317c95d87876cb058d64c8d))
* **internal:** codegen related update ([b38e485](https://github.com/ToricLabs/datagrid-python/commit/b38e48539cf573deb543c5a4b3e1c9a001494c6b))
* **internal:** codegen related update ([8e61214](https://github.com/ToricLabs/datagrid-python/commit/8e61214d9e0c146005e00bf1dfdd3563af952acd))
* **internal:** codegen related update ([a2a5915](https://github.com/ToricLabs/datagrid-python/commit/a2a5915b64fc7c52da27ffb39f95d63e7b39e69c))
* **internal:** codegen related update ([e44f3ba](https://github.com/ToricLabs/datagrid-python/commit/e44f3ba933e4c22292f33126ffd804e7459c4331))
* **internal:** codegen related update ([31f7bfd](https://github.com/ToricLabs/datagrid-python/commit/31f7bfdeabb11f65d7c4c6548475b1a856147c11))
* **internal:** codegen related update ([6597ed4](https://github.com/ToricLabs/datagrid-python/commit/6597ed414dcb7e2a1bd03163f3bf26fa7d0ba27f))
* **internal:** fix some typos ([d7bf113](https://github.com/ToricLabs/datagrid-python/commit/d7bf11367981380729d2eee052e0bcd5bc2c5837))
* update SDK settings ([#3](https://github.com/ToricLabs/datagrid-python/issues/3)) ([dd5ded3](https://github.com/ToricLabs/datagrid-python/commit/dd5ded35ca67baa02693285fcde3f5ac85d8feee))


### Documentation

* fix typos ([647dc35](https://github.com/ToricLabs/datagrid-python/commit/647dc35d4c22fcf7964b5df9e512b6213c6ed71b))
* **readme:** example snippet for client context manager ([34d4dc9](https://github.com/ToricLabs/datagrid-python/commit/34d4dc9bf14f6d6aef814c7055a415873bc3aef5))
